Skip to contents

Summarise the derived exposure rows

Usage

summarizeExposure(connection)

Arguments

connection

A connection from connectGaia().

Value

A data frame with, per exposure concept and source value, the number of rows and persons, the period covered and the mean value.