Runs backbone.ingest_datasource(): loads the dataset's JSON-LD metadata, downloads the source data and loads it into PostGIS, then cleans the geometry and adds the local projection.
Arguments
- connection
A connection from
connectGaia().- tableId
Catalog identifier of the dataset, for example
"us_2014_2019_monthly_pm25_by_county_cdc".- shell
Shell used by the database to run the dataset's ETL scripts.