Inserts locations and their residence history into the working schema and builds the point geometry (EPSG:4326) from latitude and longitude.
Arguments
- connection
A connection from
connectGaia().- location
A data frame with
location_id,latitudeandlongitude, and optionallyaddress_1,address_2,city,state,zip,county,location_source_value,country_concept_idandcountry_source_value.- locationHistory
A data frame with
location_id,entity_id(the person),start_date,end_date, and optionallyrelationship_type_concept_id(default 2052496995, OMOP GIS "Patient Residence") anddomain_id(default 1147314, Person). Gaia assigns an exposure to a person only whendomain_idis 1147314.