R/exposure.R
summarizeExposure.Rd
Summarise the derived exposure rows
summarizeExposure(connection)
A connection from connectGaia().
connectGaia()
A data frame with, per exposure concept and source value, the number of rows and persons, the period covered and the mean value.